module Tolq::Parsers::Xliff
  # Unparses a tolq response to xliff suitable
  # As opposed to other unparsers, requires the original,
  # AND the target language code
  # Assumes single file per xliff
  class Unparser
    # Unparses the tolq response
    #
    # @param tolq_response [Hash] A parsed response from our api
    # @return [String] A xliff formatted string
    def from_tolq_response(tolq_response, original:, target_language_code:)
      translations = tolq_response['translations'].values.first
      translate_xliff(translations, original, target_language_code).to_s
    end

    # Unparses a translations hash of key => translation
    #
    # @param translations [Hash] A hash of translations with key => translation
    # @return [String] A xliff formatted string
    def from_hash(translations, original:, target_language_code:)
      translate_xliff(translations, original, target_language_code).to_s
    end

    private

    def translate_xliff(translations, xliff_text, target_language_code)
      xliff = XLIFFer::XLIFF.new(xliff_text)
      xliff.files.each.with_index do |file, file_idx|
        file.target_language = target_language_code
        file.strings.each do |string|
          if translation = translations["#{file_idx}-#{string.id}"]
            string.target = translation
          end
        end
      end
      xliff
    end
  end
end
